@@ -21,25 +21,33 @@ namespace Botan {
 class BOTAN_DLL Randpool : public RandomNumberGenerator
    {
    public:
-      void randomize(byte[], u32bit);
+      void randomize(byte[], size_t);
       bool is_seeded() const { return seeded; }
       void clear();
       std::string name() const;
 
-      void reseed(u32bit bits_to_collect);
+      void reseed(size_t bits_to_collect);
       void add_entropy_source(EntropySource* es);
-      void add_entropy(const byte input[], u32bit length);
+      void add_entropy(const byte input[], size_t length);
 
-      Randpool(BlockCipher* cipher, MessageAuthenticationCode* mac,
-               u32bit pool_blocks = 32,
-               u32bit iterations_before_reseed = 128);
+      /**
+      * @param cipher a block cipher to use
+      * @param mac a message authentication code to use
+      * @param pool_blocks how many cipher blocks to use for the pool
+      * @param iterations_before_reseed how many times we'll use the
+      * internal state to generate output before reseeding
+      */
+      Randpool(BlockCipher* cipher,
+               MessageAuthenticationCode* mac,
+               size_t pool_blocks = 32,
+               size_t iterations_before_reseed = 128);
 
       ~Randpool();
    private:
       void update_buffer();
       void mix_pool();
 
-      u32bit ITERATIONS_BEFORE_RESEED, POOL_BLOCKS;
+      size_t ITERATIONS_BEFORE_RESEED, POOL_BLOCKS;
       BlockCipher* cipher;
       MessageAuthenticationCode* mac;
 
